SystemOrganization addCategory: #'PVpubTests-AnalogClock'!

TestCase subclass: #AnalogClockTest
	instanceVariableNames: 'iCalTextMorph1 iCalTextMorph2 myClockIF clock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PVpubTests-AnalogClock'!

!AnalogClockTest commentStamp: 'pv 8/1/2011 22:42' prior: 0!
An AnalogClockTest is the parent of two classes used for tests. Since unit tests and acceptance tests have several things in common, the commonalities have been factored out to AnalogClockTest.

Instance Variables
	clock:					<AnalogClock>
	iCalTextMorph1:		<TextMorph>
	iCalTextMorph2:		<Object>
	myclockIF 				<AnalogClockInterface>

clock
	- access the application

iCalTextMorph1
	- a sample ical-text

iCalTextMorph2
	- another sample ical-text

myClockIF
	- access the interface of the application
!

AnalogClockTest subclass: #AnalogClockAcceptanceTest
	instanceVariableNames: 'clockRC'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PVpubTests-AnalogClock'!

!AnalogClockAcceptanceTest commentStamp: 'pv 10/23/2010 13:13' prior: 0!
An AnalogClockAcceptanceTest is for a human tester and shows him several features of the application.

Instance Variables
	clock:		<Object>
	iCalSummary1:		<Object>
	iCalSummary2:		<Object>
	iCalTextMorph1:		<Object>
	iCalTextMorph2:		<Object>

clock
	- xxxxx

iCalSummary1
	- xxxxx

iCalSummary2
	- xxxxx

iCalTextMorph1
	- xxxxx

iCalTextMorph2
	- xxxxx
!

!AnalogClockAcceptanceTest methodsFor: 'running' stamp: 'pv 5/25/2011 23:11'!
setUp 	
	super setUp.
	"This is for acceptance test where things are shown with time intervals long enough for a user to judge"
	self timeout: 120. ! !

!AnalogClockAcceptanceTest methodsFor: 'testing' stamp: 'pv 8/20/2011 11:14'!
testConfigPanelIncDec
	"proves that options from configuration panel work"
	| messages |
	myClockIF initializeConfigPanel.
	myClockIF reset.
	messages := Array
				with: #inc
				with: #incrementIsHour
				with: #dec
				with: #incrementIsMin.
	messages
		do: [:each | 
			myClockIF configPanel perform: each.
			self waitSeconds: 2].
	myClockIF removeConfigPanel! !

!AnalogClockAcceptanceTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:17'!
testConfigPanelStart
	"proves that options from configuration panel work"
	myClockIF initializeConfigPanel.
	myClockIF reset.
	"previous tests should not have any influence"
	myClockIF configPanel toggleStartStop.
	self waitSeconds: 2.
	myClockIF configPanel toggleStartStop.
	self waitSeconds: 2.
	myClockIF removeConfigPanel! !

!AnalogClockAcceptanceTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:17'!
testConfigPanelStartStop
	"proves that options from configuration panel work"
	myClockIF initializeConfigPanel.
	myClockIF configPanel toggleStartStop.
	self waitSeconds: 2.
	myClockIF configPanel toggleStartStop.
	self waitSeconds: 2.
	myClockIF removeConfigPanel! !

!AnalogClockAcceptanceTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:16'!
testConfigPanelStop
	"proves that options from configuration panel work"
	myClockIF initializeConfigPanel.
	myClockIF configPanel toggleStartStop.
	self waitSeconds: 2.
	myClockIF removeConfigPanel! !

!AnalogClockAcceptanceTest methodsFor: 'testing' stamp: 'pv 8/20/2011 10:50'!
testDisplayCalendarEvent
	(myClockIF spiraClockOn)
		ifFalse: [myClockIF toggleSpiraClock].
	self displayCalendarEvent: iCalTextMorph1.
	self waitSeconds: 2.
	self displayCalendarEvent: iCalTextMorph2.
	self waitSeconds: 2! !

!AnalogClockAcceptanceTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:16'!
testHalo
	| messages |
	messages := Array
				with: #toggleConfigPanel
				with: #toggleDate
				with: #toggleSpiraClock
				with: #toggleTickmarks.
	"iterate over actions and add self waitSeconds in each
	iteration. "
	messages
		do: [:each | 
			myClockIF perform: each.
			self waitSeconds: 2.
			myClockIF perform: each.
			self waitSeconds: 2]! !

!AnalogClockAcceptanceTest methodsFor: 'performance evaluation' stamp: 'pv 8/15/2011 22:30'!
testSecondsWatchhandJitter
	self waitSeconds: 100.
	self assert: myClockIF jitterOk! !

!AnalogClockTest class methodsFor: 'metrics' stamp: 'pv 6/2/2011 18:08'!
Loc
	| instanceLoc classLoc |
	instanceLoc := classLoc := 0.
	(PackageInfo named: 'PVpubTests-AnalogClock') classes do:
		[:class |
			instanceLoc := class linesOfCode + instanceLoc.
			classLoc := class class linesOfCode + classLoc].
	Transcript show: 'instanceLoc=', instanceLoc asString, ', classLoc=', classLoc asString ! !

!AnalogClockTest methodsFor: 'running' stamp: 'pv 5/25/2011 19:15'!
createTextMorph1 

	| nearEventEndString nearEventStartString string tm |
	tm := TextMorph new 
		contents: 'BEGIN:VCALENDAR
PRODID:-//K Desktop Environment//NONSGML KOrganizer 3.5//EN
VERSION:2.0
BEGIN:VEVENT
DTSTAMP:20071023T145443Z
ORGANIZER;CN=Pascal Vollmer:MAILTO:pascal.vollmer@ieee.org
CREATED:20071022T231929Z
UID:KOrganizer-1239936027.943
SEQUENCE:0
LAST-MODIFIED:20071022T231929Z
SUMMARY:test a bit
CLASS:PUBLIC
PRIORITY:5
DTSTART:sssssssssssssssZ
DTEND:eeeeeeeeeeeeeeeZ
TRANSP:OPAQUE
END:VEVENT

END:VCALENDAR

'.
	nearEventStartString := (DateAndTime now + 10 minutes) asICalString.
	nearEventEndString := (DateAndTime now + 30 minutes) asICalString.
	string := String fromString: tm contents asString.
	string := string 
		replaceStrings: (Array with: 'sssssssssssssss' -> nearEventStartString
		with: 'eeeeeeeeeeeeeee' -> nearEventEndString).
	tm contents: string.
	^tm! !

!AnalogClockTest methodsFor: 'running' stamp: 'pv 5/25/2011 19:15'!
createTextMorph2 

	| nearEventEndString nearEventStartString string tm |
	tm := TextMorph new 
		contents: 'BEGIN:VCALENDAR
PRODID:-//K Desktop Environment//NONSGML KOrganizer 3.5//EN
VERSION:2.0
BEGIN:VEVENT
DTSTAMP:20071023T145443Z
ORGANIZER;CN=Pascal Vollmer:MAILTO:pascal.vollmer@ieee.org
CREATED:20071022T231929Z
UID:KOrganizer-1239936027.943
SEQUENCE:0
LAST-MODIFIED:20071022T231929Z
SUMMARY:laugh a lot
CLASS:PUBLIC
PRIORITY:5
DTSTART:sssssssssssssssZ
DTEND:eeeeeeeeeeeeeeeZ
TRANSP:OPAQUE
END:VEVENT

END:VCALENDAR

'.
	nearEventStartString := (DateAndTime now + 40 minutes) asICalString.
	nearEventEndString := (DateAndTime now + 60 minutes) asICalString.
	string := String fromString: tm contents asString.
	string := string 
		replaceStrings: (Array with: 'sssssssssssssss' -> nearEventStartString
		with: 'eeeeeeeeeeeeeee' -> nearEventEndString).
	tm contents: string.
	^tm! !

!AnalogClockTest methodsFor: 'private' stamp: 'pv 8/1/2011 22:23'!
displayCalendarEvent: aTextMorph
	| dropEvent |
	dropEvent := DropEvent new.
	dropEvent 
		setPosition: myClockIF center 
		contents: aTextMorph 
		hand: myClockIF activeHand.
	myClockIF handleDropMorph: dropEvent.
	self waitSeconds: 2.
! !

!AnalogClockTest methodsFor: 'initialize-release' stamp: 'pv 5/27/2011 20:37'!
iCalSummary1
	"This shall correspond to the SUMMARY in TextMorph1"
	^ 'test a bit'
	! !

!AnalogClockTest methodsFor: 'initialize-release' stamp: 'pv 5/28/2011 00:12'!
iCalSummary2 
	"This shall correspond to the SUMMARY in TextMorph2"
	^ 'laugh a lot'
	! !

!AnalogClockTest methodsFor: 'private' stamp: 'pv 8/1/2011 22:24'!
oneCycle
	myClockIF doOneCycleNow.
! !

!AnalogClockTest methodsFor: 'running' stamp: 'pv 8/20/2011 07:23'!
setUp
	clock := AnalogClock new openInWorld.
	myClockIF := clock clockIF.
	self oneCycle.
	iCalTextMorph1 := self createTextMorph1.
	iCalTextMorph2 := self createTextMorph2! !

!AnalogClockTest methodsFor: 'running' stamp: 'pv 8/1/2011 22:25'!
tearDown

	myClockIF delete.
	iCalTextMorph1 delete.
	iCalTextMorph2 delete.! !

!AnalogClockTest methodsFor: 'testing' stamp: 'pv 5/25/2011 19:50'!
testConfigPanelIncDec
	^ self subclassResponsibility.! !

!AnalogClockTest methodsFor: 'testing' stamp: 'pv 5/25/2011 19:52'!
testConfigPanelStart
	^ self subclassResponsibility ! !

!AnalogClockTest methodsFor: 'testing' stamp: 'pv 5/25/2011 19:52'!
testConfigPanelStartStop
	^ self subclassResponsibility ! !

!AnalogClockTest methodsFor: 'testing' stamp: 'pv 5/25/2011 19:53'!
testConfigPanelStop
	^ self subclassResponsibility ! !

!AnalogClockTest methodsFor: 'testing' stamp: 'pv 5/25/2011 19:53'!
testDisplayCalendarEvent
	^ self subclassResponsibility ! !

!AnalogClockTest methodsFor: 'testing' stamp: 'pv 5/25/2011 19:54'!
testHalo
	^ self subclassResponsibility ! !

!AnalogClockTest methodsFor: 'private' stamp: 'pv 5/25/2011 19:56'!
waitSeconds: aValue
	| timeAfter deadline |
	deadline := Time now addSeconds: aValue.
	["clock world doOneCycleNow."
	self oneCycle.
	timeAfter := Time now.
	timeAfter < deadline] 
		whileTrue.! !

AnalogClockTest subclass: #AnalogClockUnitTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PVpubTests-AnalogClock'!

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 08:07'!
checkConfigPanelStart
	"proves that options from configuration panel work"
	| radian |
	myClockIF initializeConfigPanel.
	myClockIF configPanel toggleStartStop.
	"stop"
	myClockIF configPanel toggleStartStop.
	"start"
	self oneCycle.
	"display in order to measure"
	radian := myClockIF watchhandSec radian.
	(Delay forMilliseconds: 1100) wait.
	self oneCycle.
	self assert: myClockIF watchhandSec radian ~= radian.
	myClockIF removeConfigPanel! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 08:08'!
checkConfigPanelStop
	"proves that options from configuration panel work"
	| radian |
	myClockIF initializeConfigPanel.
	myClockIF configPanel toggleStartStop.
	self oneCycle.
	radian := myClockIF watchhandSec radian.
	(Delay forMilliseconds: 1100) wait.
	self oneCycle.
	self assert: myClockIF watchhandSec radian = radian.
	myClockIF removeConfigPanel! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:22'!
checkForMovementOf: watchhand 
	| delta radian radianLag1 |
	radianLag1 := myClockIF watchhandMin radian.
	(Delay forSeconds: 1) wait.
	radian := myClockIF watchhandMin radian.
	radian < radianLag1
		ifTrue: [delta := radian + (Float pi * 2.0) - radianLag1
			"treat less probable case first"]
		ifFalse: [delta := radian - radianLag1].
	^ delta < (Float pi / 3.0)! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:21'!
displayCalendarEventFrom: spiral 
	myClockIF spiraClockOn
		ifFalse: [myClockIF toggleSpiraClock].
	self displayCalendarEvent: iCalTextMorph1.
	self assert: (spiral eventsWithText: self iCalSummary1) size = 1.
	self displayCalendarEvent: iCalTextMorph2.
	self assert: (spiral eventsWithText: self iCalSummary1) size = 1.
	self assert: (spiral eventsWithText: self iCalSummary2) size = 1! !

!AnalogClockUnitTest methodsFor: 'running' stamp: 'pv 5/27/2011 12:08'!
setUp 	
	super setUp.
	"This is for unit test where the longest method is testDisplayCalendarEventWithSizeChange"
	self timeout: 15. ! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 08:04'!
testConfigPanelIncDec
	"proves that options from configuration panel work"
	| stimulusResponse |
	myClockIF initializeConfigPanel.
	stimulusResponse := #(#(#inc #watchhandMin ) #(#incrementIsHour #watchhandHour ) #(#dec #watchhandHour ) #(#incrementIsMin #watchhandMin ) ).
	stimulusResponse
		do: [:each | 
			myClockIF configPanel perform: each first.
			self
				checkForMovementOf: (myClockIF perform: each second)].
	myClockIF removeConfigPanel! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 5/28/2011 00:55'!
testConfigPanelStart
	"proves that options from configuration panel work"
	| |

	self checkConfigPanelStart ! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 5/28/2011 00:54'!
testConfigPanelStartStop
	self checkConfigPanelStart.
	self checkConfigPanelStop.! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 5/28/2011 00:56'!
testConfigPanelStop
	"proves that options from configuration panel work"
	| |
	self checkConfigPanelStop ! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:17'!
testDisplayCalendarEvent
	self displayCalendarEventFrom: myClockIF spiral! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:21'!
testDisplayCalendarEventWithLargeSize
	| spiral |
	myClockIF extent: 1400 @ 1400.
	spiral := myClockIF spiral.
	self displayCalendarEventFrom: spiral! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:19'!
testDisplayCalendarEventWithMediumSize
	| spiral |
	myClockIF extent: 700 @ 700.
	spiral := myClockIF spiral.
	self displayCalendarEventFrom: spiral! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:19'!
testDisplayCalendarEventWithSmallSize
	| spiral |
	myClockIF extent: 350 @ 350.
	spiral := myClockIF spiral.
	self displayCalendarEventFrom: spiral! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 5/28/2011 00:39'!
testHalo
	self toggleConfigPanel.
	self toggleDate.
	self toggleSpiraClock.
	self toggleTickmarks.
! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 12:20'!
toggleConfigPanel
	"assuming that config panel is not active"
	myClockIF toggleConfigPanel.
	self assert: myClockIF configPanel notNil.

	myClockIF toggleConfigPanel.
	self assert: myClockIF configPanel isNil! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:21'!
toggleDate
	myClockIF toggleDate.
	self assert: myClockIF dateOn not.
	myClockIF toggleDate.
	self assert: myClockIF dateOn! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:20'!
toggleSpiraClock
	myClockIF toggleSpiraClock.
	self assert: myClockIF spiraClockOn.
	myClockIF toggleSpiraClock.
	self assert: myClockIF spiraClockOn not! !

!AnalogClockUnitTest methodsFor: 'testing' stamp: 'pv 8/20/2011 07:18'!
toggleTickmarks
	myClockIF toggleTickmarks.
	self assert: myClockIF tickmarksOn not.
	myClockIF toggleTickmarks.
	self assert: myClockIF tickmarksOn! !

Object subclass: #AnalogClockTestDocumentation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PVpubTests-AnalogClock'!

!AnalogClockTestDocumentation commentStamp: 'pv 8/1/2011 22:37' prior: 0!
AnalogClockTestProjectManual - (a poor man's) Project Manual


0. How to download

From SqueakSource please download

PVpubTests-AnalogClock-pv


1. How to invoke the tests for the application

open TestRunner and select 

1.1 AnalogClockUnitTest - if you want to run fast unit tests
1.2 AnalogClockAcceptanceTest - if you want to run slow acceptance tests.


2. Requirements

Each requirement has a unique identifier like 'RQF001'. The abbreviation RQF is for functional requirements. RQN is for non-functional requirements. 
We try to flag methods with the requirements they implement. This is done following the proposal from http://wiki.squeak.org/squeak/381. In order to find the (most important) methods which implement a requirement: select the requirement's identifier, type cmd-n and browse the list. 
Find in parenthesis after the RQxyyy the release number where the requirement is planned to be implemented. If there is more than one release number, replanning has taken place. Find in parenthesis at the end the release number where the requirement has been implemented. "R2" for instance is for the monticello package with the suffix "*.2". For the release-plan see 3.

2.1 functional Requirements

---everything resolved above this line---
RQF001 


2.2 non-functional Requirements

---everything resolved above this line---
RQN001 (R35) bring code coverage to 85% ()


3. Releases and Quality 

3.1 Metrics on Releases

R13  (PVpubTests-AnalogClock.13.mcz, )
Summary: added two tests

R14  (PVpub-AnalogClock.14.mcz, 5 September 2010, 12:50:40.39 am)
Summary: added AnalogClockTestProjectManual

R15  (PVpub-AnalogClock.15.mcz, upload failed)
Summary: made the difference between acceptance tests and unit tests

R16  (PVpub-AnalogClock.16.mcz, 19 October 2010, 11:07:07.77 pm)
Summary: added AnalogClockTestProjectManual

R17  (PVpub-AnalogClock.17.mcz, )
Summary: unit tests now need roughly 
Metrics: code coverage=71%

R18  (PVpub-AnalogClock.18.mcz, )
Summary: xx
Metrics: code coverage=xx

R19  (PVpub-AnalogClock.19.mcz, )
Summary: xx
Metrics: code coverage=xx

R20  (PVpub-AnalogClock.20.mcz, )
Corresponding version of PVpub-AnalogClock: PVpub-AnalogClock-pv.53.mcz
Metrics: see AnalogClockProjectManual
Summary: Introduced AnalogClockAcceptanceTest>>testSecondsWatchhandJitter

R21  (PVpub-AnalogClock.21.mcz, )
Summary: 
Metrics: code coverage=xx


3.2 Reviews

Reviews are welcome!! I am a Squeak newbie, I am sure I make a lot of mistakes and I would like to learn more.


4. Bugs

(Find in parenthesis at the start of the bug description the release number where the bug has been discovered. Find in parenthesis at the end of the bug description the release number where the bug has been fixed or confirmed to be fixed. "R2" for instance is for the monticello package with the suffix "*.2". Sometimes there is an explanation about the fix.)

B001 

	
6. Author

P. Vollmer 4.11.2006-01.08.2011
mailto: pascal.vollmer@ieee.org!
